==> cosmo_1.6.0.tar.gz: cosmo/man/writeConFile.Rd <==
\name{writeConFile}
\alias{writeConFile}
\title{Converts an object of class 'constraintSet' into a text file}
\description{
  This function converts an object of class \code{constraintSet} or a
  list of such objects into a text file. 
}
\usage{
  writeConFile(constraints, stringOutput=TRUE, outputFile="constraints.txt")
}
\arguments{
  \item{constraints}{object of class \code{constraintSet} or list of
    objects of class \code{constraintSet} which is to be converted in a text format}
  \item{stringOutput}{logical, whether the constraint should be written
    as a string. If FALSE, the constraint is written as a text file} 
  \item{outputFile}{path and name of the constraint text file to be created}
}
\details{
  Both the string and the text file can be used to submit constraints
  directly to the COSMO web
  application, which is an alternative to the GUI
  application. The text file has the advantage of being more easy to
  read and to load for future use.
}
\value{
NULL
A single text file is created, by default in the working directory.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}
}
\seealso{
  \code{\link[base]{constraintSet}},
  \code{\link[base]{readConFile}}

}
\examples{
set <- makeConSet(4,c("B","P","V","B"),c(4,50,NA,4))
con1 <- makeBoundCon(1,2)
con2 <- makePalCon(1,4,0.5)
con3 <- makeSubMotifCon("TATA",0.6)
con4 <- makePosFreqCon("2","A",0.5)
con5 <- makePosFreqCon("All","G",0.4)
conSet <- addCon(set,list(con1,con2,con3,con4,con5),c(2,NA,NA,1,3))
conString <- writeConFile(conSet)
}
\keyword{misc}

==> cosmo_1.18.0.tar.gz: cosmo/man/writeConFile.Rd <==
\name{writeConFile}
\alias{writeConFile}
\title{Converts an object of class 'constraintSet' into a text file}
\description{
  This function converts an object of class \code{constraintSet} or a
  list of such objects into a text file. 
}
\usage{
  writeConFile(constraints, stringOutput=TRUE, outputFile="constraints.txt")
}
\arguments{
  \item{constraints}{object of class \code{constraintSet} or list of
    objects of class \code{constraintSet} which is to be converted in a
    text format} 
  \item{stringOutput}{logical, whether the constraint should be written
    as a string. If FALSE, the constraint is written as a text file} 
  \item{outputFile}{path and name of the constraint text file to be created}
}
\details{
  Both the string and the text file can be used to submit constraints
  directly to the COSMO web
  application, which is an alternative to the GUI
  application. The text file has the advantage of being more easy to
  read and to load for future use.
}
\value{
NULL
A single text file is created, by default in the working directory.
}
\author{
Fabian Gallusser, \email{fgallusser@berkeley.edu}
}
\seealso{
  \code{\link[cosmo:constraintSet-class]{constraintSet}},
  \code{\link{readConFile}}

}
\examples{
set <- makeConSet(4,c("B","P","V","B"),c(4,50,NA,4))
con1 <- makeBoundCon(1,2)
con2 <- makePalCon(1,4,0.5)
con3 <- makeSubMotifCon("TATA",0.6)
con4 <- makePosFreqCon("2","A",0.5)
con5 <- makePosFreqCon("All","G",0.4)
conSet <- addCon(set,list(con1,con2,con3,con4,con5),c(2,NA,NA,1,3))
conString <- writeConFile(conSet)
}
\keyword{misc}
